@@ -1,14 +1,7 @@
 use super::super::c;
 use super::super::conv::{borrowed_fd, ret, ret_owned_fd, ret_send_recv, send_recv_len};
 use super::super::fd::BorrowedFd;
-#[cfg(not(any(
-    target_os = "freebsd",
-    target_os = "ios",
-    target_os = "macos",
-    target_os = "netbsd"
-)))]
-use super::ext::in6_addr_new;
-use super::ext::in_addr_new;
+use super::ext::{in6_addr_new, in_addr_new};
 #[cfg(not(windows))]
 use super::{encode_sockaddr_unix, SocketAddrUnix};
 #[cfg(not(any(target_os = "redox", target_os = "wasi")))]
@@ -380,23 +373,9 @@ pub(crate) fn socketpair(
 
 #[cfg(not(any(target_os = "redox", target_os = "wasi")))]
 pub(crate) mod sockopt {
-    #[cfg(not(any(
-        target_os = "freebsd",
-        target_os = "ios",
-        target_os = "macos",
-        target_os = "netbsd"
-    )))]
-    use super::in6_addr_new;
-    use super::{c, in_addr_new, BorrowedFd};
+    use super::{c, in6_addr_new, in_addr_new, BorrowedFd};
     use crate::net::sockopt::Timeout;
-    #[cfg(not(any(
-        target_os = "freebsd",
-        target_os = "ios",
-        target_os = "macos",
-        target_os = "netbsd"
-    )))]
-    use crate::net::Ipv6Addr;
-    use crate::net::{Ipv4Addr, SocketType};
+    use crate::net::{Ipv4Addr, Ipv6Addr, SocketType};
     use crate::{as_mut_ptr, io};
     use core::convert::TryInto;
     use core::time::Duration;
@@ -645,31 +624,43 @@ pub(crate) mod sockopt {
         setsockopt(fd, c::IPPROTO_IP as _, c::IP_ADD_MEMBERSHIP, mreq)
     }
 
-    #[cfg(not(any(
-        target_os = "dragonfly",
-        target_os = "freebsd",
-        target_os = "ios",
-        target_os = "macos",
-        target_os = "netbsd",
-        target_os = "openbsd"
-    )))]
     #[inline]
-    pub(crate) fn set_ipv6_join_group(
+    pub(crate) fn set_ipv6_add_membership(
         fd: BorrowedFd<'_>,
         multiaddr: &Ipv6Addr,
         interface: u32,
     ) -> io::Result<()> {
+        #[cfg(not(any(
+            target_os = "dragonfly",
+            target_os = "freebsd",
+            target_os = "ios",
+            target_os = "macos",
+            target_os = "openbsd",
+            target_os = "netbsd",
+            target_os = "illumos",
+            target_os = "solaris",
+            target_os = "haiku",
+            target_os = "l4re"
+        )))]
+        use c::IPV6_ADD_MEMBERSHIP;
+        #[cfg(any(
+            target_os = "dragonfly",
+            target_os = "freebsd",
+            target_os = "ios",
+            target_os = "macos",
+            target_os = "openbsd",
+            target_os = "netbsd",
+            target_os = "illumos",
+            target_os = "solaris",
+            target_os = "haiku",
+            target_os = "l4re"
+        ))]
+        use c::IPV6_JOIN_GROUP as IPV6_ADD_MEMBERSHIP;
+
         let mreq = to_ipv6mr(multiaddr, interface);
-        setsockopt(fd, c::IPPROTO_IPV6 as _, c::IPV6_ADD_MEMBERSHIP, mreq)
+        setsockopt(fd, c::IPPROTO_IPV6 as _, IPV6_ADD_MEMBERSHIP, mreq)
     }
 
-    #[cfg(not(any(
-        target_os = "dragonfly",
-        target_os = "freebsd",
-        target_os = "ios",
-        target_os = "macos",
-        target_os = "netbsd"
-    )))]
     #[inline]
     pub(crate) fn set_ip_drop_membership(
         fd: BorrowedFd<'_>,
@@ -680,22 +671,41 @@ pub(crate) mod sockopt {
         setsockopt(fd, c::IPPROTO_IP as _, c::IP_DROP_MEMBERSHIP, mreq)
     }
 
-    #[cfg(not(any(
-        target_os = "dragonfly",
-        target_os = "freebsd",
-        target_os = "ios",
-        target_os = "macos",
-        target_os = "netbsd",
-        target_os = "openbsd",
-    )))]
     #[inline]
-    pub(crate) fn set_ipv6_leave_group(
+    pub(crate) fn set_ipv6_drop_membership(
         fd: BorrowedFd<'_>,
         multiaddr: &Ipv6Addr,
         interface: u32,
     ) -> io::Result<()> {
+        #[cfg(not(any(
+            target_os = "dragonfly",
+            target_os = "freebsd",
+            target_os = "ios",
+            target_os = "macos",
+            target_os = "openbsd",
+            target_os = "netbsd",
+            target_os = "illumos",
+            target_os = "solaris",
+            target_os = "haiku",
+            target_os = "l4re"
+        )))]
+        use c::IPV6_DROP_MEMBERSHIP;
+        #[cfg(any(
+            target_os = "dragonfly",
+            target_os = "freebsd",
+            target_os = "ios",
+            target_os = "macos",
+            target_os = "openbsd",
+            target_os = "netbsd",
+            target_os = "illumos",
+            target_os = "solaris",
+            target_os = "haiku",
+            target_os = "l4re"
+        ))]
+        use c::IPV6_LEAVE_GROUP as IPV6_DROP_MEMBERSHIP;
+
         let mreq = to_ipv6mr(multiaddr, interface);
-        setsockopt(fd, c::IPPROTO_IPV6 as _, c::IPV6_DROP_MEMBERSHIP, mreq)
+        setsockopt(fd, c::IPPROTO_IPV6 as _, IPV6_DROP_MEMBERSHIP, mreq)
     }
 
     #[inline]
@@ -721,12 +731,6 @@ pub(crate) mod sockopt {
         in_addr_new(u32::from_ne_bytes(addr.octets()))
     }
 
-    #[cfg(not(any(
-        target_os = "freebsd",
-        target_os = "ios",
-        target_os = "macos",
-        target_os = "netbsd"
-    )))]
     #[inline]
     fn to_ipv6mr(multiaddr: &Ipv6Addr, interface: u32) -> c::ipv6_mreq {
         c::ipv6_mreq {
@@ -735,12 +739,6 @@ pub(crate) mod sockopt {
         }
     }
 
-    #[cfg(not(any(
-        target_os = "freebsd",
-        target_os = "ios",
-        target_os = "macos",
-        target_os = "netbsd"
-    )))]
     #[inline]
     fn to_ipv6mr_multiaddr(multiaddr: &Ipv6Addr) -> c::in6_addr {
         in6_addr_new(multiaddr.octets())
@@ -752,13 +750,7 @@ pub(crate) mod sockopt {
         interface as c::c_int
     }
 
-    #[cfg(not(any(
-        target_os = "android",
-        target_os = "freebsd",
-        target_os = "ios",
-        target_os = "macos",
-        target_os = "netbsd"
-    )))]
+    #[cfg(not(target_os = "android"))]
     #[inline]
     fn to_ipv6mr_interface(interface: u32) -> c::c_uint {
         interface as c::c_uint
