@@ -57,9 +57,9 @@
 #![allow(unsafe_code)]
 
 use super::super::c;
-use crate::imp::fd::{AsFd, AsRawFd, BorrowedFd, RawFd};
-#[cfg(not(feature = "rustc-dep-of-std"))]
-use crate::imp::fd::{FromFd, FromRawFd, IntoFd, IntoRawFd};
+use crate::fd::{AsFd, AsRawFd, BorrowedFd, RawFd};
+#[cfg(feature = "std")]
+use crate::fd::{FromFd, FromRawFd, IntoFd, IntoRawFd};
 use crate::imp::linux_raw::syscalls::{epoll_add, epoll_create, epoll_del, epoll_mod, epoll_wait};
 use crate::io::{self, OwnedFd};
 use alloc::vec::Vec;
@@ -208,12 +208,12 @@ impl<'a> Context for Borrowing<'a> {
 ///
 /// This may be used with [`OwnedFd`], or higher-level types like
 /// [`std::fs::File`] or [`std::net::TcpStream`].
-#[cfg(not(feature = "rustc-dep-of-std"))]
+#[cfg(feature = "std")]
 pub struct Owning<'context, T: IntoFd + FromFd> {
     _phantom: PhantomData<&'context T>,
 }
 
-#[cfg(not(feature = "rustc-dep-of-std"))]
+#[cfg(feature = "std")]
 impl<'context, T: IntoFd + FromFd> Owning<'context, T> {
     /// Creates a new empty `Owning`.
     #[allow(clippy::new_without_default)] // This is a specialized type that doesn't need to be generically constructible.
@@ -225,7 +225,7 @@ impl<'context, T: IntoFd + FromFd> Owning<'context, T> {
     }
 }
 
-#[cfg(not(feature = "rustc-dep-of-std"))]
+#[cfg(feature = "std")]
 impl<'context, T: AsFd + IntoFd + FromFd> Context for Owning<'context, T> {
     type Data = T;
     type Target = BorrowedFd<'context>;
@@ -383,21 +383,21 @@ impl<Context: self::Context> Epoll<Context> {
     }
 }
 
-#[cfg(not(feature = "rustc-dep-of-std"))]
+#[cfg(feature = "std")]
 impl<'context, T: AsFd + IntoFd + FromFd> AsRawFd for Epoll<Owning<'context, T>> {
     fn as_raw_fd(&self) -> RawFd {
         self.epoll_fd.as_raw_fd()
     }
 }
 
-#[cfg(not(feature = "rustc-dep-of-std"))]
+#[cfg(feature = "std")]
 impl<'context, T: AsFd + IntoFd + FromFd> IntoRawFd for Epoll<Owning<'context, T>> {
     fn into_raw_fd(self) -> RawFd {
         self.epoll_fd.into_raw_fd()
     }
 }
 
-#[cfg(not(feature = "rustc-dep-of-std"))]
+#[cfg(feature = "std")]
 impl<'context, T: AsFd + IntoFd + FromFd> FromRawFd for Epoll<Owning<'context, T>> {
     unsafe fn from_raw_fd(fd: RawFd) -> Self {
         Self {
@@ -407,21 +407,21 @@ impl<'context, T: AsFd + IntoFd + FromFd> FromRawFd for Epoll<Owning<'context, T
     }
 }
 
-#[cfg(not(feature = "rustc-dep-of-std"))]
+#[cfg(feature = "std")]
 impl<'context, T: AsFd + IntoFd + FromFd> AsFd for Epoll<Owning<'context, T>> {
     fn as_fd(&self) -> BorrowedFd<'_> {
         self.epoll_fd.as_fd()
     }
 }
 
-#[cfg(not(feature = "rustc-dep-of-std"))]
+#[cfg(feature = "std")]
 impl<'context, T: AsFd + IntoFd + FromFd> From<Epoll<Owning<'context, T>>> for OwnedFd {
     fn from(epoll: Epoll<Owning<'context, T>>) -> OwnedFd {
         epoll.epoll_fd
     }
 }
 
-#[cfg(not(feature = "rustc-dep-of-std"))]
+#[cfg(feature = "std")]
 impl<'context, T: AsFd + IntoFd + FromFd> From<OwnedFd> for Epoll<Owning<'context, T>> {
     fn from(fd: OwnedFd) -> Self {
         Self {
