@@ -46,7 +46,7 @@ use std::path::{Component, Components, Iter, Path, PathBuf};
 /// }
 /// ```
 ///
-/// Users can then call `touch("foo")`, `touch(cstr!("foo"))`,
+/// Users can then call `touch("foo")`, `touch(zstr!("foo"))`,
 /// `touch(Path::new("foo"))`, or many other things.
 ///
 /// [`AsRef`]: std::convert::AsRef
@@ -67,9 +67,6 @@ pub trait Arg {
     where
         Self: 'b;
 
-    /// Returns a view of this string as a byte slice.
-    fn as_maybe_utf8_bytes(&self) -> &[u8];
-
     /// Runs a closure with `self` passed in as a `&ZStr`.
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -131,11 +128,6 @@ impl Arg for &str {
         ))
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self.as_bytes()
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -172,11 +164,6 @@ impl Arg for &String {
         self.as_str().into_z_str()
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self.as_bytes()
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -215,11 +202,6 @@ impl Arg for String {
         ))
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self.as_bytes()
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -259,11 +241,6 @@ impl Arg for &OsStr {
         ))
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self.as_bytes()
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -302,11 +279,6 @@ impl Arg for &OsString {
         self.as_os_str().into_z_str()
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self.as_bytes()
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -346,11 +318,6 @@ impl Arg for OsString {
         ))
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self.as_bytes()
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -390,11 +357,6 @@ impl Arg for &Path {
         ))
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self.as_os_str().as_bytes()
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -436,11 +398,6 @@ impl Arg for &PathBuf {
         self.as_path().into_z_str()
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        PathBuf::as_path(self).as_os_str().as_bytes()
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -480,11 +437,6 @@ impl Arg for PathBuf {
         ))
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self.as_os_str().as_bytes()
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -522,11 +474,6 @@ impl Arg for &ZStr {
         Ok(Cow::Borrowed(self))
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self.to_bytes()
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -561,11 +508,6 @@ impl Arg for &ZString {
         Ok(Cow::Borrowed(self))
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self.to_bytes()
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -600,11 +542,6 @@ impl Arg for ZString {
         Ok(Cow::Owned(self))
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self.as_bytes()
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -647,11 +584,6 @@ impl<'a> Arg for Cow<'a, str> {
         ))
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self.as_bytes()
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -695,11 +627,6 @@ impl<'a> Arg for Cow<'a, OsStr> {
         ))
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self.as_bytes()
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -735,11 +662,6 @@ impl<'a> Arg for Cow<'a, ZStr> {
         Ok(self)
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self.to_bytes()
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -779,11 +701,6 @@ impl<'a> Arg for Component<'a> {
         ))
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self.as_os_str().as_bytes()
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -825,11 +742,6 @@ impl<'a> Arg for Components<'a> {
         ))
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self.as_path().as_os_str().as_bytes()
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -871,11 +783,6 @@ impl<'a> Arg for Iter<'a> {
         ))
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self.as_path().as_os_str().as_bytes()
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -914,11 +821,6 @@ impl Arg for &[u8] {
         ))
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -957,11 +859,6 @@ impl Arg for &Vec<u8> {
         ))
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -1000,11 +897,6 @@ impl Arg for Vec<u8> {
         ))
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
@@ -1046,11 +938,6 @@ impl Arg for DecInt {
         ))
     }
 
-    #[inline]
-    fn as_maybe_utf8_bytes(&self) -> &[u8] {
-        self.as_ref().as_os_str().as_bytes()
-    }
-
     #[inline]
     fn into_with_z_str<T, F>(self, f: F) -> io::Result<T>
     where
